import Head from 'next/head'
import React, { Component, useEffect, useState } from 'react';
import moment from 'jalali-moment'
const CryptoJS = require("crypto-js");
import { whalesAPI } from '../lib/data'

export default function WhaleAlert(props){
    const [whales, setWhales] = useState([]);
    const [whaleMinimze, setWhaleMinimize] = useState(true);
    const [whaleActive, setWhaleActive] = useState(true);
    const [done, setDone] = useState(false);
    const salt = Date.now()
    const token = CryptoJS.MD5(salt+'313').toString();
    useEffect(()=>{
        if(!done){
            setDone(true)
            setTimeout(()=>{
                whalesAPI(salt,token).then(data=>{
                    if(data.data.length!=0){
                        setWhales(data.data)
                    }
                })
            },2000)
        }
    },[setDone,done,whalesAPI,setWhales,salt,token])
    const whaleToggle = () => {
        setWhaleActive(!whaleActive)
    }
    const whaleHistory = () => {
        setWhaleMinimize(!whaleMinimze)
    }
    const proprice = (num,persian=true) => {
        let result = num.toString();
        result = result.replace(/(\d)(?=(\d{3})+(?!\d))/g, '$1,');
        if(persian){
          var id = ['۰', '۱', '۲', '۳', '۴', '۵', '۶', '۷', '۸', '۹'];
          result = result.replace(/[0-9]/g, function (w) {return id[+w];});
          if(result.includes('.')){ result = result.split('.')[0] }
        }
        return result;
    }
    return (<div className={`whaleAlert-body animated fadeInUp${whaleMinimze ? ' minimize' : ''}${whales.length==0 ? ' disabled' : ''}${whaleActive ? ' active' : ''}`}>
        <div className="whaleAlert-call" onClick={whaleToggle}><img src="/img/icon-notification.svg"/></div>
        <div className="whaleAlert-header">
            <div className="whaleAlert-header-btn" onClick={whaleToggle}><img src="/img/icon-close-circle-white.svg"/><span>بستن</span></div>
            <div className="whaleAlert-header-btn" onClick={whaleHistory}><img src="/img/icon-arrow-circle-up-white.svg"/><span>تاریخچه</span></div>
            <b>{whaleMinimze ? 'فعالیت نهنگ' : 'فعالیت نهنگ ها'}</b>
        </div>
        {whales ? whales.map((whale,whalekey)=>{
            let whale_from='آدرس ناشناس',whale_to='آدرس ناشناس',txLink='';
            if(whale.from_owner!='unknown'){ whale_from=whale.from_owner }
            if(whale.to_owner!='unknown'){ whale_to=whale.to_owner }
            if(whale.blockchain=='ethereum'){ txLink='https://etherscan.io/tx/0x'+whale.transaction_hash }else if(whale.blockchain=='ripple'){ txLink='https://xrpscan.com/tx/'+whale.transaction_hash }else if(whale.blockchain=='tron'){ txLink='https://tronscan.org/#/transaction/'+whale.transaction_hash }else if(whale.blockchain=='bitcoin'){ txLink='https://www.blockchain.com/explorer/transactions/btc/'+whale.transaction_hash }
            return (<div className="whaleAlert animated fadeIn" key={`whaleAlert-${whalekey}`}>
            <div className="whaleAlert-text">
                <b>{proprice(whale.amount)}</b> واحد <b>{whale.symbol}</b> در شبکه <b>{whale.blockchain}</b>، به ارزش <b><bdi>${proprice(whale.amount_usd)}</bdi></b> از <b title={whale.from_address}>{whale_from}</b> به <b title={whale.to_address}>{whale_to}</b> منتقل شد. ({moment(whale.created_at).locale('fa').fromNow()}) {txLink!='' ? <a href={txLink} target="_blank">مشاهده</a> : ''}
            </div>
            </div>)
        }) : ''}
    </div>);
}